package com.kakao.sdk.talk.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import kotlinx.android.parcel.Parcelize

/**
 * 메시지 전송 API 호출 결과
 *
 * @property successfulReceiverUuids 메시지 전송에 성공한 대상의 uuid
 * @property failureInfos (복수의 전송 대상을 지정한 경우) 전송 실패한 일부 대상의 오류 정보
 * @author kevin.kang. Created on 2019-09-20..
 */
@Parcelize
data class MessageSendResult(
    val successfulReceiverUuids: List<String>?,
    @SerializedName("failure_info") val failureInfos: List<MessageFailureInfo>?
) : Parcelable

/**
 * 복수의 친구를 대상으로 메시지 전송 API 호출 시 대상 중 일부가 실패한 경우 오류 정보를 제공합니다.
 *
 * @property code 오류 코드
 * @property receiverUuids 이 에러로 인해 실패한 대상 목록
 */
@Parcelize
data class MessageFailureInfo(val code: Int, val msg: String, val receiverUuids: List<String>) :
    Parcelable